Random enhancements.

- [X] usage needs to document priority and deadline formats
- [X] colour-code the output
- [X] {n} most important tasks
- [X] pick tasks at random
- [X] some way to mark a section of Markdown for inclusion in the default
      output
- [X] add totals to summaries
